#!/usr/bin/wish
#########################################################################
#                       Latency Over Time
#
# This script was automatically generated from the Spirent Communications
# ScriptCenter program, and is used to run a SmartMetrics Latency
# Over Time test between two cards
#
#########################################################################

package require smartlib
package require libcmds


################ PARAMETERS ##################

set LinkIP 10.254.1.250
set timeInterval 15
set txHub  0
set txSlot 0
set txPort 0
set rxHub  0
set rxSlot 1
set rxPort 0
set burstCount 6
upvar #0 L3_STREAM_IP trafProtocol
set framesize       60
set numOfStreams    10
set framesPerStream 2000
set srcIP           10.8.1.40
set incSrcIPBy      0.0.0.0
set dstIP           10.8.1.30
set incDstIPBy      0.0.0.0
set gateway         10.8.1.1
set srcMAC          0x00.0x00.0x00.0x00.0x00.0x00
set incSrcMACBy     0x00.0x00.0x00.0x00.0x00.0x01
set dstMAC          0x00.0x00.0x00.0x00.0x01.0x00
set incDstMACBy     0x00.0x00.0x00.0x00.0x00.0x01

set RxSrcIP         $dstIP
set RxIncSrcIPBy    $incDstIPBy
set RxDstIP         $srcIP
set RxIncDstIPBy    $incSrcIPBy
set RxGateway       10.8.1.1
set RxSrcMAC        $dstMAC
set RxIncSrcMACBy   $incDstMACBy
set RxDstMAC        $srcMAC
set RxIncDstMACBy   $incSrcMACBy
set maxTimeout      [expr round($numOfStreams*$framesPerStream/14880)+10]

################ END PARAMETERS ##################

puts "Linking..."
EX_SocketLink $LinkIP 16385 $::RESERVE_NONE
# reserve the ports
CheckError HTSlotReserve $txHub $txSlot
CheckError HTSlotReserve $rxHub $rxSlot


puts "\nClearing all streams"
EX_ClearStreams $txHub $txSlot $txPort
EX_ClearStreams $rxHub $rxSlot $rxPort


puts "Setting Traffic on $txHub $txSlot $txPort..."
EX_SetMLTrafficMulti $txHub $txSlot $txPort $trafProtocol $numOfStreams \
              -uiFrameLength $framesize \
              -startSrcIP $srcIP \
              -incrSrcIP $incSrcIPBy \
              -startDestIP $dstIP \
              -incrDestIP $incDstIPBy \
              -gateway $gateway \
              -startSrcMAC $srcMAC \
              -incrSrcMAC $incSrcMACBy \
              -startDestMAC $dstMAC \
              -incrDestMAC $incDstMACBy \
              -ulBurstCount $framesPerStream


puts "Setting Traffic on $rxHub $rxSlot $rxPort..."
EX_SetMLTrafficMulti $rxHub $rxSlot $rxPort $trafProtocol $numOfStreams \
              -uiFrameLength $framesize \
              -startSrcIP $RxSrcIP \
              -incrSrcIP $RxIncSrcIPBy \
              -startDestIP $RxDstIP \
              -incrDestIP $RxIncDstIPBy \
              -gateway $RxGateway \
              -startSrcMAC $RxSrcMAC \
              -incrSrcMAC $RxIncSrcMACBy \
              -startDestMAC $RxDstMAC \
              -incrDestMAC $RxIncDstMACBy \
              -ulBurstCount $framesPerStream


puts "\nSetting Up Latency Over Time Test..."
EX_SetLatencyOverTime $rxHub $rxSlot $rxPort $timeInterval


puts "\nTransmitting Smart Metrics..."
set card [list $txHub $txSlot $txPort]
EX_TransmitSmartMetrics [list $card] $maxTimeout


puts "\nGetting histogram data..."
EX_DisplayLatencyOverTime $rxHub $rxSlot $rxPort

puts "Setting Capture"
EX_SetCaptureMode $ON $CAPTURE_ALL $rxHub $rxSlot $rxPort
after 2000

puts "Running"
HTRun $HTRUN $txHub $txSlot $txPort
after 2000
HTRun $HTSTOP $txHub $txSlot $txPort

puts "Checking Capture Count"
set capCount [EX_ReturnCaptureCount $rxHub $rxSlot $rxPort]
puts "Capture count is $capCount"

set index 0
puts "Checking Capture size"
set capSize [EX_ReturnCapturePacketLength $index $rxHub $rxSlot $rxPort]
puts "The size of packet $index is $capSize"

puts "Getting Capture"
#set capPacket [EX_ReturnCapturePacket $index $rxHub $rxSlot $rxPort]
EX_DisplayCapture 0 $burstCount $rxHub $rxSlot $rxPort

puts "Done"
EX_UnLink



